/*
 *  Copyright (C) 1999, 2000 Bruno Pires Marinho
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _MAIN_WINDOW_H
#define _MAIN_WINDOW_H

#include "gtm.h"

void menu_toolbar_set_state (GtkCList *file_list);

void menu_toolbar_set_auto_dl (GtkCList *file_list);

GtkWidget *main_window_create (gchar *geometry);

void toolbar_update_style (void);

void main_window_update_dl_info_page_visibility (void);

void remove_cmd (GtkWidget *widget, gpointer data);

void stats_cmd (GtkWidget *widget, gpointer data);

void start_cmd (GtkWidget *widget, gpointer data);

void stop_cmd (GtkWidget *widget, gpointer data);

void restart_cmd (GtkWidget *widget, gpointer data);

void properties_cmd (GtkWidget *widget, gpointer data);

#endif /* _MAIN_WINDOW_H */
